pub struct RunWithPreExec<'t> {
pub pre_exec_bash_code: Cow<'t, str>,
pub bash_settings: BashSettings,
pub bash_path: Option<Cow<'t, Path>>,
}Fields
pre_exec_bash_code: Cow<'t, str>bash_settings: BashSettingsbash_path: Option<Cow<'t, Path>>Implementations
Sourceimpl<'t> RunWithPreExec<'t>
impl<'t> RunWithPreExec<'t>
Sourcepub fn command<S: AsRef<OsStr> + AsRef<str>>(
&self,
command_path: &str,
args: impl AsRef<[S]>,
) -> Command
pub fn command<S: AsRef<OsStr> + AsRef<str>>( &self, command_path: &str, args: impl AsRef<[S]>, ) -> Command
Return a command that executes the given command and args
directly if pre_exec_bash_code is empty (after trim), or
executes “bash” or the given bash_path with the given
pre-exec code plus exec to the given command and args. The
command_path has to be a str since it must be possible to
represent it as unicode to be made part of bash code.